==> alfred-ui-native-components-0.0.72.tgz: package/ui/atoms/textInput/block/extraLarge/default/index.tsx <==
import React, { FC, useState } from 'react';
import { autoCapitalizeTypesEnum, keyboardTypesEnum, TextInputModels } from '../../../textInputModels';
import { TextInput, Text } from 'react-native';
import { styles } from '../../styles';

export const TextInputExtraLarge: FC<TextInputModels> = ({
  keyboardType= keyboardTypesEnum.DEFAULT,
  autoCapitalize = autoCapitalizeTypesEnum.NONE,
  isSecureTextEntry= false,
  isError= false,
  isDisabled= false,
  isAutoFocus= false,
  maxLength= 255,
  onChangeText,
  errorText,
  defaultValue,
  placeholder,
}) => {
  const [isFocused, setIsFocused] = useState(false);
  const [maxLengthCompleted, setMaxLengthCompleted] = useState(false);

  const handleChangeText = (val: string) => {
    val.length === maxLength ? setMaxLengthCompleted(true) : setMaxLengthCompleted(false);
    onChangeText(val);
  };

  return (
    <>
      <TextInput
        secureTextEntry={isSecureTextEntry}
        autoFocus={isAutoFocus}
        defaultValue={defaultValue}
        editable={!isDisabled}
        maxLength={maxLength}
        autoCapitalize={autoCapitalize}
        placeholderTextColor={
          isDisabled
            ? styles.textInputDisabled.placeholderText.color
            : styles.textInput.placeholderText.color
        }
        placeholder={placeholder}
        onChangeText={handleChangeText}
        onFocus={() => setIsFocused(true)}
        onEndEditing={() => setIsFocused(false)}
        keyboardType={keyboardType}
        style={[
          styles.textInput,
          styles.textInputExtraLight,
          isFocused && styles.textInputActive,
          isDisabled && styles.textInputDisabled,
          isError && styles.textInputError,
          maxLengthCompleted && styles.textInputError,
        ]}
      />
      {isError && <Text numberOfLines={1} style={styles.textInputErrorText}>{errorText}</Text>}
    </>
  );
};

==> alfred-ui-native-components-0.0.158.tgz: package/ui/atoms/textInput/block/extraLarge/default/index.tsx <==
import React, { FC, useState } from 'react';
import { autoCapitalizeTypesEnum, keyboardTypesEnum, TextInputModels } from '../../../textInputModels';
import { TextInput, Text } from 'react-native';
import { styles } from '../../styles';

export const TextInputExtraLarge: FC<TextInputModels> = ({
  keyboardType= keyboardTypesEnum.DEFAULT,
  autoCapitalize = autoCapitalizeTypesEnum.NONE,
  isSecureTextEntry= false,
  isError= false,
  isDisabled= false,
  isAutoFocus= false,
  maxLength= 255,
  onChangeText,
  errorText,
  defaultValue,
  placeholder,
}) => {
  const [isFocused, setIsFocused] = useState(false);
  const [maxLengthCompleted, setMaxLengthCompleted] = useState(false);

  const handleChangeText = (val: string) => {
    val.length === maxLength ? setMaxLengthCompleted(true) : setMaxLengthCompleted(false);
    onChangeText?.(val);
  };

  return (
    <>
      <TextInput
        secureTextEntry={isSecureTextEntry}
        autoFocus={isAutoFocus}
        defaultValue={defaultValue}
        editable={!isDisabled}
        maxLength={maxLength}
        autoCapitalize={autoCapitalize}
        placeholderTextColor={
          isDisabled
            ? styles.textInputDisabled.placeholderText.color
            : styles.textInput.placeholderText.color
        }
        placeholder={placeholder}
        onChangeText={handleChangeText}
        onFocus={() => setIsFocused(true)}
        onEndEditing={() => setIsFocused(false)}
        keyboardType={keyboardType}
        style={[
          styles.textInput,
          styles.textInputExtraLarge,
          isFocused && styles.textInputActive,
          isDisabled && styles.textInputDisabled,
          isError && styles.textInputError,
          maxLengthCompleted && styles.textInputError,
        ]}
      />
      {isError && <Text numberOfLines={1} style={styles.textInputErrorText}>{errorText}</Text>}
    </>
  );
};
